/*
 * Copyright (C) 2011 Giuseppe Calà <jiveaxe@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "steamcompanion.h"
#include "dealswidget.h"
#include "librarywidget.h"
#include "strings.h"
#include "configwidget.h"

#include <QTimer>
#include <QGraphicsLinearLayout>
#include <QWebPage>
#include <QFile>
#include <QFileInfo>
#include <QWebFrame>
#include <QNetworkCookie>
#include <QWebElementCollection>

#include <KStandardDirs>
#include <KRun>
#include <KConfigDialog>
#include <KNotification>

#include <Plasma/WebView>
#include <Plasma/Theme>
#include <Plasma/TabBar>

SteamCompanion::SteamCompanion(QObject *parent, const QVariantList &args)
    : Plasma::PopupApplet(parent, args),
      m_graphicsWidget(0),
      m_jar(0),
      m_homePage(0),
      m_specialsPage(0),
      m_libraryPage(0),
      m_tabBar(0),
      m_current_state(Solid::Networking::Status())
{
    setHasConfigurationInterface(true);
    setAspectRatioMode(Plasma::IgnoreAspectRatio);
    setPopupIcon(QLatin1String("steam-companion"));
    
    m_timer = new QTimer(this);
    connect(m_timer, SIGNAL(timeout()), this, SLOT(doNetworkActivity()));

    configChanged();

    connect(Solid::Networking::notifier(), SIGNAL(statusChanged(Solid::Networking::Status)),this,SLOT(networkStatusChanged(Solid::Networking::Status)));
}

void SteamCompanion::networkStatusChanged(Solid::Networking::Status newstate) {
    m_current_state = newstate;
    doNetworkActivity();
}

void SteamCompanion::doNetworkActivity() {
    if(m_current_state == Solid::Networking::Unknown || m_current_state == Solid::Networking::Connected) {
        startFetch();
        configChanged();
    }
    else if (m_current_state == Solid::Networking::Disconnecting)
        qDebug() << "SteamCompanion::disconnecting...";
    else if (m_current_state == Solid::Networking::Connecting)
        qDebug() << "SteamCompanion::connecting...";
    else {
        qDebug() << "SteamCompanion::NoConnection";
        QString html;
        html += QString(BEGIN).arg(m_jsPrototype);
        html += QString(NO_CONNECTION).arg(i18n("No Internet Connection ;("));
        html += END;
        m_graphicsWidget->setPreferredSize(-1, -1);

        m_dealsWidget->m_webView->setHtml(html, m_cssDir);
        m_libraryWidget->m_webView->setHtml(html, m_cssDir);
        emit sizeHintChanged(Qt::PreferredSize);
    }
}

SteamCompanion::~SteamCompanion()
{
    delete m_graphicsWidget;
    delete m_jar;
    delete m_homePage;
    delete m_specialsPage;
}

QGraphicsWidget *SteamCompanion::graphicsWidget()
{
    if (!m_graphicsWidget) {
        m_layout = new QGraphicsLinearLayout();
        m_layout->setContentsMargins(0, 0, 0, 0);
        m_layout->setSpacing(0);
        m_layout->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));

        m_graphicsWidget = new QGraphicsWidget(this);
        m_graphicsWidget->setLayout(m_layout);
        m_graphicsWidget->setPreferredSize(370,440);
        m_graphicsWidget->setMinimumSize(150, 48);

        m_tabBar = new Plasma::TabBar;
        m_tabBar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        m_tabBar->nativeWidget()->installEventFilter(this);
        
        m_dealsWidget = new DealsWidget;
        m_libraryWidget = new LibraryWidget;
	
	m_dealsWidget->m_webView->setDragToScroll(m_showScrollBars);
	m_libraryWidget->m_webView->setDragToScroll(m_showScrollBars);

        m_tabBar->addTab(i18n("Deals"), m_dealsWidget);
        m_tabBar->addTab(i18n("Games"), m_libraryWidget);

        m_layout->addItem(m_tabBar);

        makeStylesheet();
        connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(makeStylesheet()));

        configChanged();
        doNetworkActivity();
    }

    return m_graphicsWidget;
}

void SteamCompanion::configChanged()
{
    KConfigGroup cg = config();
    m_interval = cg.readEntry("interval", 8);
    m_language = cg.readEntry("language", "english");
    m_steamID = cg.readEntry("steam_id", "");
    m_showScrollBars = cg.readEntry("show_scrollbars", false);
    
    tabBarHandler();

    m_timer->start(m_interval*3600*1000);
}

void SteamCompanion::tabBarHandler()
{
    if(m_tabBar == 0)
        return;
    
    if(m_steamID.isEmpty()) {
        m_tabBar->setTabBarShown(false);
	m_tabBar->setCurrentIndex(0);
    }
    else
        m_tabBar->setTabBarShown(true);
    
    m_dealsWidget->m_webView->setDragToScroll(!m_showScrollBars);
    m_libraryWidget->m_webView->setDragToScroll(!m_showScrollBars);
}

void SteamCompanion::makeStylesheet()
{
    const QString search = "desktoptheme/" +
                           Plasma::Theme::defaultTheme()->themeName() +
                           "/stylesheets/steamcompanion.css";
    QString path =  KStandardDirs::locate("data", search);
    if (path.isEmpty()) {
        path =  KStandardDirs::locate("data", "desktoptheme/default/stylesheets/steamcompanion.css");
    }
    if (path.isEmpty()) {
        QColor backgroundColor =
                Plasma::Theme::defaultTheme()->color(Plasma::Theme::BackgroundColor);
        QColor textColor = Plasma::Theme::defaultTheme()->color(Plasma::Theme::TextColor);
        QColor altBackgroundColor = backgroundColor;
        altBackgroundColor.setHsv(altBackgroundColor.hue(), altBackgroundColor.saturation(),
                (altBackgroundColor.value() < 128)
                ? backgroundColor.value() + 40 : backgroundColor.value() - 40,
                altBackgroundColor.alpha());
        QString css = QString(CSS);
        KStandardDirs dirs;
        m_cssDir = dirs.saveLocation("data", "plasma_applet_steamcompanion");

        QFile file(m_cssDir + "/steamcompanion.css");
        if (file.open(QIODevice::WriteOnly)) {
            file.write(css.toUtf8());
        }
    } else {
        m_cssDir = QFileInfo(path).absolutePath() + '/';
    }
}

void SteamCompanion::createConfigurationInterface(KConfigDialog *parent)
{
    mConfigWidget = new ConfigWidget( parent );

    mConfigWidget->setUpdateInterval(m_interval);

    mConfigWidget->setSteamId( m_steamID );

    mConfigWidget->setCurrentLanguage( m_language );
    
    mConfigWidget->setShowScrollbars( m_showScrollBars );

    parent->setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
    parent->addPage( mConfigWidget->config, i18n( "General" ), icon() );

    connect( parent, SIGNAL( applyClicked() ), this, SLOT( applyConfig() ) );
    connect( parent, SIGNAL( okClicked() ), this, SLOT( applyConfig() ) );
    connect(mConfigWidget, SIGNAL(enableApply()), parent, SLOT(settingsModified()));
}

void SteamCompanion::applyConfig()
{
    m_interval        = mConfigWidget->updateInterval();
    m_language        = mConfigWidget->currentLanguage();
    m_steamID         = mConfigWidget->steamId();
    m_showScrollBars  = mConfigWidget->showScrollBars();

    KConfigGroup cg = config();
    cg.writeEntry("interval", m_interval);
    cg.writeEntry("language", m_language);
    cg.writeEntry("steam_id", m_steamID);
    cg.writeEntry("show_scrollbars", m_showScrollBars);

    doNetworkActivity();
}

void SteamCompanion::startFetch()
{
    m_currPage = 1;
    m_serverTime = 0;
    m_serverEndTime = 0;
    m_gamesArray.clear();
    m_filterText.clear();
    m_specials.clear();
    m_spotlights.clear();
    m_ownedgames.clear();
    m_hasNext = false;
    m_hasSpotlight = false;
    m_hasDailyDeal = false;
    m_jsPrototype = "";

    m_newSpecials.clear();
    
    QNetworkCookie languageCookie("Steam_Language", m_language.toAscii());

    if(!m_jar)
        m_jar = new QNetworkCookieJar;
    m_jar->setCookiesFromUrl(QList<QNetworkCookie>() << languageCookie, QUrl("http://store.steampowered.com"));

    if(!m_homePage) {
        m_homePage = new QWebPage;
        QWebSettings *settings = m_homePage->settings();
        settings->setAttribute(QWebSettings::AutoLoadImages, false);
        connect(m_homePage, SIGNAL(loadFinished(bool)),this, SLOT(loadSpotlightPageFinished()));
    }

    m_homePage->networkAccessManager()->setCookieJar(m_jar);
    m_homePage->mainFrame()->load(QUrl("http://store.steampowered.com"));

    if(!m_specialsPage) {
        m_specialsPage = new QWebPage;
        QWebSettings *settings = m_specialsPage->settings();
        settings->setAttribute(QWebSettings::AutoLoadImages, false);
        connect(m_specialsPage, SIGNAL(loadFinished(bool)),this, SLOT(loadSpecialsPageFinished()));
    }

    m_specialsPage->networkAccessManager()->setCookieJar(m_jar);

    if(!m_libraryPage) {
        m_libraryPage = new QWebPage;
        QWebSettings *settings = m_libraryPage->settings();
        settings->setAttribute(QWebSettings::AutoLoadImages, false);
        connect(m_libraryPage, SIGNAL(loadFinished(bool)),this, SLOT(loadLibraryPageFinished()));
    }
    
    m_libraryPage->networkAccessManager()->setCookieJar(m_jar);
}

void SteamCompanion::loadSpecialsPageFinished()
{
    m_hasNext = false;
    QWebFrame* webFrame = m_specialsPage->mainFrame();

    QWebElementCollection gamesEC = webFrame->findAllElements("#search_results a");

    foreach(QWebElement e, gamesEC) {
        if(e.findFirst("div.col.search_name h4").toPlainText().trimmed() == "Uninitialized")
            continue;

        if(e.findFirst("div.col.search_price").toPlainText().trimmed().isEmpty())
            continue;

        Game *special        = new Game;
        special->title       = e.findFirst("div.col.search_name h4").toPlainText().trimmed();
        special->description = e.findFirst("div.col.search_name p").toPlainText().trimmed();
        special->originalPrice  = e.findFirst("div.col.search_price strike").toPlainText().trimmed();
        QWebElement *strike = new QWebElement(e.findFirst("div.col.search_price strike"));
        strike->removeFromDocument();
        special->finalPrice     = e.findFirst("div.col.search_price").toPlainText().trimmed();
        special->img            = e.findFirst("div.col.search_capsule img").attribute("src").trimmed();

        QRegExp rx("(\\d+)");
        rx.indexIn(special->img);
        special->gameId = rx.cap(1).toUInt();

        m_specials.append(special);

        m_newSpecials << special->gameId;

        delete strike;
    }

    QWebElementCollection pagesEC     = webFrame->findAllElements("div.search_pagination_right a");

    for(int i = 0; i < pagesEC.count(); i++) {
        if(pagesEC.at(i).toPlainText().contains(">>"))
            m_hasNext = true;
    }

    if(m_hasNext) {
        m_currPage++;
        m_hasNext = false;
        m_specialsPage->mainFrame()->load(QUrl("http://store.steampowered.com/search/?sort_by=Name&sort_order=ASC&specials=1&page=" + QString::number(m_currPage)));
    }
    else {
        if(!m_steamID.isEmpty())
            m_libraryPage->mainFrame()->load(QUrl("http://steamcommunity.com/profiles/" + m_steamID + "/games?tab=all&sort=name&l=" + m_language));
        else
            populateEmptyLibraryView();
        populateWebView();
    }
}

void SteamCompanion::loadLibraryPageFinished()
{
    QWebFrame* webFrame = m_libraryPage->mainFrame();

    if(webFrame->findFirstElement("#BG_top h1").toPlainText().isEmpty()) {
        populateEmptyLibraryView();
        return;
    }

    QWebElementCollection gamesEC = webFrame->findAllElements("div.gameListRow");

    foreach(QWebElement e, gamesEC) {
        Game *game        = new Game;
        game->title       = e.findFirst("div.gameListRowItem h4").toPlainText().trimmed();
        game->description = e.findFirst("div.gameListRowItem h5").toPlainText().trimmed();
        game->img         = e.findFirst("div.gameLogo img").attribute("src").trimmed();
        game->link        = e.findFirst("div.gameLogo a").attribute("href").trimmed();

        QRegExp rx("(\\d+)");
        rx.indexIn(e.findFirst("div.gameLogo a").attribute("href").trimmed());
        game->gameId = rx.cap(1).toUInt();

        m_ownedgames.append(game);
    }

    QWebElementCollection scriptElements  = webFrame->findAllElements("script");

    foreach(QWebElement e, scriptElements) {
        if(e.toPlainText().contains("var rgGames")) {
            m_gamesArray = e.toPlainText();
        }
    }

    QWebElementCollection formElements  = webFrame->findAllElements("form");
    foreach(QWebElement e, formElements) {
        if(e.hasAttribute("id"))
            continue;
        else
            m_filterText = e.toPlainText();
    }

    // fill
    populateLibraryView();
}

void SteamCompanion::populateLibraryView()
{
    int i = 2;
    QStringList cssTitleClasses;
    cssTitleClasses << "title0" << "title1";

    QStringList cssDescriptonClasses;
    cssDescriptonClasses << "description0" << "description1";
    
    QString html;
    html += QString(BEGIN2).arg(m_jsPrototype).arg(m_gamesArray);
    html += BEGIN_TABLE;
    html += QString(HEADER_LINE).arg(QString::number(m_ownedgames.count()) + i18n(" Games"));
    html += QString(FORM_LINE).arg(m_filterText);

    foreach(Game *game, m_ownedgames) {
        html += QString(TWO_LINE_LIBRARY).arg(cssTitleClasses.at(i%2))
                                         .arg("game_" + QString::number(game->gameId))
                                         .arg(game->link)
                                         .arg(game->img)
                                         .arg(game->title)
                                         .arg(game->link)
                                         .arg(game->title);
        ++i;
    }

    html += END_TABLE;
    html += END;
    m_graphicsWidget->setPreferredSize(-1, -1);

    m_libraryWidget->m_webView->setHtml(html, m_cssDir);
    emit sizeHintChanged(Qt::PreferredSize);
}

void SteamCompanion::populateEmptyLibraryView()
{
    QString html;
    html += QString(BEGIN2).arg(m_jsPrototype).arg(m_gamesArray);
    html += BEGIN_TABLE;
    html += QString(NO_STEAM_ID).arg(i18n("You need to enter a valid Steam Id in Settings."));
    html += END_TABLE;
    html += END;
    m_graphicsWidget->setPreferredSize(-1, -1);

    m_libraryWidget->m_webView->setHtml(html, m_cssDir);
    emit sizeHintChanged(Qt::PreferredSize);
}

void SteamCompanion::populateWebView()
{
    int i = 2;
    QStringList cssTitleClasses;
    cssTitleClasses << "title0" << "title1";

    QStringList cssDescriptonClasses;
    cssDescriptonClasses << "description0" << "description1";

    QStringList cssDiscountClasses;
    cssDiscountClasses << "discount0" << "discount1";

    QString html;
    html += QString(BEGIN).arg(m_jsPrototype);
    html += BEGIN_TABLE;
    if(m_hasSpotlight) {
        html += QString(HEADER_LINE).arg(i18n("Spotlight"));
        foreach(Game *spotlight, m_spotlights) {
            QUrl url(spotlight->link);
            if(url.scheme() == "steam") {
                spotlight->link = QString("http://store.steampowered.com/app/") + QString::number(spotlight->gameId);
            }
            html += QString(SPOTLIGHT_LINE).arg(spotlight->link).arg(spotlight->img).arg(spotlight->title).arg(spotlight->description);

            if(!spotlight->discount.isEmpty())
                html += QString(DISCOUNT_LINE).arg(cssDiscountClasses.at(i%2))
                                              .arg(spotlight->discount)
                                              .arg(spotlight->originalPrice)
                                              .arg(spotlight->finalPrice);
        }
    }

    if(m_hasDailyDeal) {
        if(m_serverTime != 0)
            html += QString(JS_SERVER_TIME).arg(QString::number(m_serverTime));
        
        html += QString(HEADER_LINE).arg(i18n("Today's Deal"));
        
        html += QString(SPOTLIGHT_LINE).arg(m_dailydeal.link)
                                       .arg(m_dailydeal.img)
                                       .arg(m_dailydeal.title)
                                       .arg(m_dailydeal.description);
                                       
        html += QString(DISCOUNT_LINE).arg(cssDiscountClasses.at(i%2))
                                      .arg(m_dailydeal.discount)
                                      .arg(m_dailydeal.originalPrice)
                                      .arg(m_dailydeal.finalPrice);
        if(m_serverEndTime != 0) {
            html += QString(TIMER_LINE);
            html += QString(JS_TIMER).arg(QString::number(m_serverEndTime));
        }
    }

    html += QString(HEADER_LINE).arg(QString::number(m_specials.count()) + i18n(" Specials"));

    foreach(Game *special, m_specials) {
        QRegExp rx("(\\d+)");
        rx.indexIn(special->img);
        QString gameId = rx.cap(1);

        QString subFolder = "app";
        if(special->img.contains("/subs/"))
            subFolder = "sub";
        
        float oldprice = QString(special->originalPrice).replace(QChar(0x20AC),"") // euro   symbol
                                                        .replace(QChar(0x0024),"") // dollar symbol
                                                        .replace(QChar(0x00A3),"") // pound  symbol
                                                        .replace("--","00")
                                                        .toFloat();
                                                   
        float newprice = QString(special->finalPrice).replace(QChar(0x20AC),"") // euro   symbol
                                                     .replace(QChar(0x0024),"") // dollar symbol
                                                     .replace(QChar(0x00A3),"") // pound  symbol
                                                     .replace("--","00")
                                                     .toFloat();

        int discount = (1.0-newprice/oldprice)*100;
    
        html += QString(TWO_COLUMNS_LINE).arg(cssTitleClasses.at(i%2))
                                         .arg("http://store.steampowered.com/" + subFolder + "/" + gameId)
                                         .arg(special->img)
                                         .arg(special->title)
                                         .arg("http://store.steampowered.com/" + subFolder + "/" + gameId)
                                         .arg(special->title);
                                               
        html += QString(ONE_COLUMN_LINE).arg(cssDescriptonClasses.at(i%2))
                                        .arg(special->description);

        if(!special->originalPrice.isEmpty())
            html += QString(DISCOUNT_LINE).arg(cssDiscountClasses.at(i%2))
                                          .arg("-" + QString::number(discount) + "%")
                                          .arg(special->originalPrice)
                                          .arg(special->finalPrice);
        else
            html += QString(ORPHAN_LINE).arg(cssDescriptonClasses.at(i%2))
                                        .arg(special->finalPrice);
        ++i;
    }

    html += END_TABLE;
    html += END;
    m_graphicsWidget->setPreferredSize(-1, -1);

    m_dealsWidget->m_webView->setHtml(html, m_cssDir);
    emit sizeHintChanged(Qt::PreferredSize);

    // remove out dated offers
    foreach(uint gameId, m_oldSpecials) {
        if(!m_newSpecials.contains(gameId)) {
            m_oldSpecials.remove(m_oldSpecials.indexOf(gameId));
        }
    }

    // delete existing offers
    foreach(uint gameId, m_oldSpecials) {
        if(m_newSpecials.contains(gameId)) {
            m_newSpecials.remove(m_newSpecials.indexOf(gameId));
        }
    }

    const uint numberOfRows = 3;

    if(m_newSpecials.count() > 0) {
        QString message;
        for(int i = 0; i < m_newSpecials.count()-1; i++) {
            foreach(Game *special, m_specials) {
                if(special->gameId == m_newSpecials.at(i)) {
                    message += special->title;
                    break;
                }
            }
            if(i == numberOfRows-1) {
                if(numberOfRows < m_newSpecials.count())
                message += "<br>" + i18n("and others ") + QString::number(m_newSpecials.count() - numberOfRows) + i18n(" games.");
                break;
            }
            else if((i + 1) < (m_newSpecials.count() - 1))
                message += "<br>";
        }

        KNotification* specialsNotify = new KNotification("newspecials");
        specialsNotify->setTitle(i18n("<b>Steam Companion - New Specials</b>"));
        specialsNotify->setText(message);
        specialsNotify->setComponentData(KComponentData("steamcompanion"));
        specialsNotify->sendEvent();
    }

    m_oldSpecials << m_newSpecials;
}

void SteamCompanion::loadSpotlightPageFinished()
{
    QWebFrame* webFrame = m_homePage->mainFrame();

    QWebElementCollection gamesEC = webFrame->findAllElements("div.home_area_spotlight.underlined_links");

    foreach(QWebElement e, gamesEC) {
        m_hasSpotlight = true;
        Game *spotlight          = new Game;
        spotlight->title         = e.findFirst("div.spotlight_content h3").toPlainText().trimmed();
        spotlight->description   = e.findFirst("div.spotlight_body").toPlainText().trimmed();
        spotlight->originalPrice = e.findFirst("div.discount_original_price").toPlainText().trimmed();
        spotlight->finalPrice    = e.findFirst("div.discount_final_price").toPlainText().trimmed();
        spotlight->discount      = e.findFirst("div.discount_pct").toPlainText().trimmed();
        spotlight->img           = e.findFirst("div.spotlight_img img").attribute("src").trimmed();
        spotlight->link          = e.findFirst("div.spotlight_img a").attribute("href").trimmed();

        QRegExp rx("(\\d+)");
        rx.indexIn(spotlight->link);
        spotlight->gameId = rx.cap(1).toUInt();

        m_spotlights.append(spotlight);
    }

    QWebElement dailyDealImgElement      = webFrame->findFirstElement("div.cap img");
    QWebElement dailyDealLinkElement     = webFrame->findFirstElement("div.cap a");
    QWebElement dailyDealContentElement  = webFrame->findFirstElement("div.dailydeal div.title");
    QWebElement dailyDealOldPriceElement = webFrame->findFirstElement("div.discount_block.game_purchase_discount div.discount_original_price");
    QWebElement dailyDealNewPriceElement = webFrame->findFirstElement("div.discount_block.game_purchase_discount div.discount_final_price");
    QWebElement dailyDiscountElement     = webFrame->findFirstElement("div.discount_block.game_purchase_discount div.discount_pct");

    if(!dailyDealImgElement.attribute("src").isEmpty()) {
        m_hasDailyDeal = true;
        m_dailydeal.title         = dailyDealContentElement.toPlainText().trimmed();
        m_dailydeal.img           = dailyDealImgElement.attribute("src").trimmed();
        m_dailydeal.link          = dailyDealLinkElement.attribute("href").trimmed();
        m_dailydeal.originalPrice = dailyDealOldPriceElement.toPlainText().trimmed();
        m_dailydeal.finalPrice    = dailyDealNewPriceElement.toPlainText().trimmed();
        m_dailydeal.discount      = dailyDiscountElement.toPlainText().trimmed();
    }

    QWebElementCollection scriptElements  = webFrame->findAllElements("script");

    foreach(QWebElement e, scriptElements) {
        QRegExp rx("(\\d{4,})");
        
        if(e.toPlainText().contains("g_ServerTime")) {
            rx.indexIn(e.toPlainText());
            m_serverTime = rx.cap(1).toInt();
        }
        else if(e.toPlainText().contains("InitDailyDealTimer")) {
            rx.indexIn(e.toPlainText());
            m_serverEndTime = rx.cap(1).toInt();
        }
        else if(e.attribute("src").contains("javascript/prototype")) {
            m_jsPrototype = e.attribute("src");
        }
    }

    m_specialsPage->mainFrame()->load(QUrl("http://store.steampowered.com/search/?sort_by=Name&sort_order=ASC&specials=1"));
}

void SteamCompanion::keyPressEvent ( QKeyEvent * event )
{
    switch( event->key() )
    {
        case Qt::Key_F5:
        {
            doNetworkActivity();
            event->accept();
            m_timer->start(m_interval*3600*1000);
            break;
        }
    }

    Plasma::Applet::keyPressEvent( event );
}

#include "steamcompanion.moc"
